@@ -113,6 +113,8 @@
 #include <syslog.h>
 #include <errno.h>
 
+#include <config.h>
+
 #include <sys/time.h>
 #include <sys/types.h>
 #include <sys/fcntl.h>
@@ -121,9 +123,21 @@
 #include <sys/ioctl.h>
 #include <sys/socket.h>
 
+#ifdef HAVE_NETAX25_AX25_H
 #include <netax25/ax25.h>
+#else
+#include <netax25/kernel_ax25.h>
+#endif
+#ifdef HAVE_NETROM_NETROM_H
 #include <netrom/netrom.h>
+#else
+#include <netax25/kernel_netrom.h>
+#endif
+#ifdef HAVE_NETROSE_ROSE_H
 #include <netrose/rose.h>
+#else
+#include <netax25/kernel_rose.h>
+#endif
 
 #include <netax25/axlib.h>
 #include <netax25/axconfig.h>
@@ -131,7 +145,6 @@
 #include <netax25/rsconfig.h>
 #include <netax25/daemon.h>
 
-#include <config.h>
 
 #include "../pathnames.h"
 
