@@ -130,10 +130,21 @@
 #include <sys/ioctl.h>
 #include <sys/file.h>
 
+#include <config.h>
+
 #include <sys/socket.h>
 
+#ifdef HAVE_NETAX25_AX25_H
 #include <netax25/ax25.h>
+#else
+#include <netax25/kernel_ax25.h>
+#endif
+#ifdef HAVE_NETROSE_ROSE_H
 #include <netrose/rose.h>
+#else
+#include <netax25/kernel_rose.h>
+#endif
+
 #include <netax25/axlib.h>
 
 #include "../pathnames.h"
