@@ -5,6 +5,8 @@
 #include <syslog.h>
 #include <signal.h>
 
+#include <config.h>
+
 #include <sys/types.h>
 #include <sys/ioctl.h>
 #include <sys/time.h>
@@ -14,17 +16,27 @@
 
 #include <net/if.h>
 #include <net/ethernet.h>
+#ifdef HAVE_NETAX25_AX25_H
 #include <netax25/ax25.h>
+#else
+#include <netax25/kernel_ax25.h>
+#endif
+#ifdef HAVE_NETROM_NETROM_H
 #include <netrom/netrom.h>
+#else
+#include <netax25/kernel_netrom.h>
+#endif
+#ifdef HAVE_NETROSE_ROSE_H
 #include <netrose/rose.h>
+#else 
+#include <netax25/kernel_rose.h>
+#endif
 
 #include <netax25/axlib.h>
 #include <netax25/axconfig.h>
 #include <netax25/daemon.h>
 #include <netax25/nrconfig.h>
 
-#include <config.h>
-
 #include "../pathnames.h"
 #include "netromd.h"
 
